@@ -23,6 +23,8 @@
 #include <QModelIndex>
 #include <QTreeWidget>
 
+#include <optional>
+
 class QLabel;
 class QTreeWidgetItem;
 class QRadioButton;
@@ -49,11 +51,6 @@ enum MyRoles {
     ObjectRole,
 };
 
-/**
- * Type used for QTreeWidgetItems
- *
- * @internal
- */
 enum ItemTypes {
     NonActionItem = 0,
     ActionItem = 1,
@@ -62,11 +59,11 @@ enum ItemTypes {
 QKeySequence primarySequence(const QList<QKeySequence> &sequences);
 QKeySequence alternateSequence(const QList<QKeySequence> &sequences);
 
-/**
+/*!
  * Mixes the KShortcutWidget into the treeview used by KShortcutsEditor. When selecting an shortcut
  * it changes the display from "CTRL-W" to the Widget.
  *
- * @bug That delegate uses KExtendableItemDelegate. That means a cell can be expanded. When selected
+ * BUG: That delegate uses KExtendableItemDelegate. That means a cell can be expanded. When selected
  * a cell is replaced by a KShortcutsEditor. When painting the widget KExtendableItemDelegate
  * reparents the widget to the viewport of the itemview it belongs to. The widget is destroyed when
  * the user selects another shortcut or explicitly issues a contractItem event. But when the user
@@ -74,7 +71,7 @@ QKeySequence alternateSequence(const QList<QKeySequence> &sequences);
  * remains as a visible artefact in your treeview. Additionally when closing your application you get
  * an assertion failure from KExtendableItemDelegate.
  *
- * @internal
+ * \internal
  */
 class KShortcutsEditorDelegate : public KExtendableItemDelegate
 {
@@ -84,16 +81,16 @@ public:
     // reimplemented to have some extra height
     QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
-    /**
+    /*!
      * Set a list of action collections to check against for conflicting
      * shortcuts.
      *
-     * @see KKeySequenceWidget::setCheckActionCollections
+     * \sa KKeySequenceWidget::setCheckActionCollections
      */
     void setCheckActionCollections(const QList<KActionCollection *> &checkActionCollections);
 
 Q_SIGNALS:
-    void shortcutChanged(const QVariant &, const QModelIndex &);
+    void shortcutChanged(const QKeySequence &, const QModelIndex &);
 public Q_SLOTS:
     void hiddenBySearchLine(QTreeWidgetItem *, bool);
 
@@ -111,30 +108,23 @@ private:
 private Q_SLOTS:
     void itemActivated(const QModelIndex &index);
 
-    /**
+    /*!
      * When the user collapses a hole subtree of shortcuts then remove eventually
      * extended items. Else we get that artefact bug. See above.
      */
     void itemCollapsed(const QModelIndex &index);
 
-    /**
+    /*!
      * If the user allowed stealing a shortcut we want to be able to undo
      * that.
      */
     void stealShortcut(const QKeySequence &seq, QAction *action);
-
-    void keySequenceChanged(const QKeySequence &);
-
-#if 0
-    void shapeGestureChanged(const KShapeGesture &);
-    void rockerGestureChanged(const KRockerGesture &);
-#endif
 };
 
-/**
+/*!
  * That widget draws the decoration for KShortCutWidget. That widget is currently the only user.
  *
- * @internal
+ * \internal
  */
 class TabConnectedWidget : public QWidget
 {
@@ -149,10 +139,10 @@ protected:
     void paintEvent(QPaintEvent *pe) override;
 };
 
-/**
+/*!
  * Edit a shortcut. Let you select between using the default shortcut and configuring your own.
  *
- * @internal
+ * \internal
  */
 class ShortcutEditWidget : public TabConnectedWidget
 {
@@ -160,22 +150,18 @@ class ShortcutEditWidget : public TabConnectedWidget
 public:
     ShortcutEditWidget(QWidget *viewport, const QKeySequence &defaultSeq, const QKeySequence &activeSeq, bool allowLetterShortcuts);
 
-    //! @see KKeySequenceWidget::setCheckActionCollections()
+    //! \sa KKeySequenceWidget::setCheckActionCollections()
     void setCheckActionCollections(const QList<KActionCollection *> &checkActionCollections);
 
-    //@{
-    //! @see KKeySequenceWidget::checkAgainstStandardShortcuts()
+    //! \sa KKeySequenceWidget::checkAgainstStandardShortcuts()
     KKeySequenceWidget::ShortcutTypes checkForConflictsAgainst() const;
     void setCheckForConflictsAgainst(KKeySequenceWidget::ShortcutTypes);
-    //@}
 
-    //@{
-    //! @see KKeySequenceWidget::checkAgainstStandardShortcuts()
+    //! \sa KKeySequenceWidget::checkAgainstStandardShortcuts()
     bool multiKeyShortcutsAllowed() const;
     void setMultiKeyShortcutsAllowed(bool);
-    //@}
 
-    //! @see KKeySequenceWidget::setComponentName
+    //! \sa KKeySequenceWidget::setComponentName
     void setComponentName(const QString &componentName);
 
     void setAction(QObject *action);
@@ -190,7 +176,7 @@ Q_SIGNALS:
     //! Emitted when the key sequence is changed.
     void keySequenceChanged(const QKeySequence &);
 
-    //! @see KKeySequenceWidget::stealShortcut()
+    //! \sa KKeySequenceWidget::stealShortcut()
     void stealShortcut(const QKeySequence &seq, QAction *action);
 
 private Q_SLOTS:
@@ -209,18 +195,13 @@ private:
     const QString m_noneText; // Translated "None" text for labels
 };
 
-#if 0
-Q_DECLARE_METATYPE(KShapeGesture)
-Q_DECLARE_METATYPE(KRockerGesture)
-#endif
-
 class KShortcutSchemesEditor : public QGroupBox
 {
     Q_OBJECT
 public:
     explicit KShortcutSchemesEditor(KShortcutsDialog *parent);
 
-    /** @return the currently selected scheme in the editor (may differ from current app's scheme.*/
+    /*! Returns the currently selected scheme in the editor (may differ from current app's scheme.*/
     QString currentScheme();
     void refreshSchemes();
     void addMoreMenuAction(QAction *action);
@@ -250,20 +231,20 @@ private:
 
 class QAction;
 
-/**
+/*!
  * A QTreeWidgetItem that can handle QActions.
  *
  * It provides undo, commit functionality for changes made. Changes are effective immediately. You
  * have to commit them or they will be undone when deleting the item.
  *
- * @internal
+ * \internal
  */
 class KShortcutsEditorItem : public QTreeWidgetItem
 {
 public:
     KShortcutsEditorItem(QTreeWidgetItem *parent, QAction *action);
 
-    /**
+    /*!
      * Destructor
      *
      * Will undo pending changes. If you don't want that. Call commitChanges before
@@ -281,10 +262,6 @@ public:
 
     QKeySequence keySequence(uint column) const;
     void setKeySequence(uint column, const QKeySequence &seq);
-#if 0
-    void setShapeGesture(const KShapeGesture &gst);
-    void setRockerGesture(const KRockerGesture &gst);
-#endif
 
     bool isModified(uint column) const;
     bool isModified() const;
@@ -306,15 +283,9 @@ private:
     //! Should the Name column be painted in bold?
     bool m_isNameBold;
 
-    //@{
-    //! The original shortcuts before user changes. 0 means no change.
-    QList<QKeySequence> *m_oldLocalShortcut = nullptr;
-    QList<QKeySequence> *m_oldGlobalShortcut = nullptr;
-#if 0
-    KShapeGesture *m_oldShapeGesture;
-    KRockerGesture *m_oldRockerGesture;
-#endif
-    //@}
+    //! The original shortcuts before user changes
+    std::optional<QList<QKeySequence>> m_oldLocalShortcut;
+    std::optional<QList<QKeySequence>> m_oldGlobalShortcut;
 
     //! The localized action name
     QString m_actionNameInTable;
@@ -329,11 +300,11 @@ private:
 // NEEDED FOR KShortcutsEditorPrivate
 #include "ui_kshortcutsdialog.h"
 
-/**
+/*!
  * This class should belong into kshortcutseditor.cpp. But kshortcutseditordelegate uses a static
  * function of this class. So for now it's here. But i will remove it later.
  *
- * @internal
+ * \internal
  */
 class KShortcutsEditorPrivate
 {
@@ -353,22 +324,8 @@ public:
     // Import shortcuts from file
     void importConfiguration(KConfigBase *config);
 
-#if 0
-    //helper functions for conflict resolution
-    bool stealShapeGesture(KShortcutsEditorItem *item, const KShapeGesture &gest);
-    bool stealRockerGesture(KShortcutsEditorItem *item, const KRockerGesture &gest);
-#endif
-
     // conflict resolution functions
     void changeKeyShortcut(KShortcutsEditorItem *item, uint column, const QKeySequence &capture);
-#if 0
-    void changeShapeGesture(KShortcutsEditorItem *item, const KShapeGesture &capture);
-    void changeRockerGesture(KShortcutsEditorItem *item, const KRockerGesture &capture);
-#endif
-
-    // private slots
-    // this invokes the appropriate conflict resolution function
-    void capturedShortcut(const QVariant &, const QModelIndex &);
 
     //! Represents the three hierarchies the dialog handles.
     struct HierarchyInfo {
@@ -377,11 +334,11 @@ public:
         QTreeWidgetItem *action = nullptr;
     };
 
-    /**
-     * Add @p action at @p level. Checks for QActions and unnamed actions
+    /*!
+     * Add \a action at \a level. Checks for QActions and unnamed actions
      * before adding.
      *
-     * @return @c true if the action was really added, @c false if not
+     * Returns \c true if the action was really added, \c false if not
      */
     bool addAction(QAction *action, QTreeWidgetItem *parent);
 
