@@ -16,7 +16,7 @@
 
 #include "kshortcutseditor.h"
 
-// The following is needed for KShortcutsEditorPrivate and QTreeWidgetHack
+// The following is needed for KShortcutsEditorPrivate
 #include "debug.h"
 #include "kshortcutsdialog_p.h"
 
@@ -60,7 +60,11 @@ KShortcutsEditor::KShortcutsEditor(QWidget *parent, ActionTypes actionType, Lett
     d->initGUI(actionType, allowLetterShortcuts);
 }
 
-KShortcutsEditor::~KShortcutsEditor() = default;
+KShortcutsEditor::~KShortcutsEditor()
+{
+    // reset all pending changes
+    undo();
+}
 
 bool KShortcutsEditor::isModified() const
 {
@@ -143,36 +147,20 @@ void KShortcutsEditor::addCollection(KActionCollection *collection, const QStrin
     // Hide Global shortcuts columns if there are no global shortcuts
     d->setGlobalColumnsHidden(!d->m_hasAnyGlobalShortcuts);
 
+    // ...And hide local shortcuts columns if there are no local shortcuts
+    d->setLocalColumnsHidden(!d->m_hasAnyLocalShortcuts);
+
     // re-enable updating
     setUpdatesEnabled(true);
 
     QTimer::singleShot(0, this, &KShortcutsEditor::resizeColumns);
 }
 
-void KShortcutsEditor::clearConfiguration()
-{
-    d->clearConfiguration();
-}
-
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-void KShortcutsEditor::importConfiguration(KConfig *config)
-{
-    d->importConfiguration(config);
-}
-#endif
-
 void KShortcutsEditor::importConfiguration(KConfigBase *config)
 {
     d->importConfiguration(config);
 }
 
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-void KShortcutsEditor::exportConfiguration(KConfig *config) const
-{
-    exportConfiguration(static_cast<KConfigBase *>(config));
-}
-#endif
-
 void KShortcutsEditor::exportConfiguration(KConfigBase *config) const
 {
     Q_ASSERT(config);
@@ -206,17 +194,12 @@ void KShortcutsEditor::writeConfiguration(KConfigGroup *config) const
 // slot
 void KShortcutsEditor::resizeColumns()
 {
-    for (int i = 0; i < d->ui.list->columnCount(); i++) {
-        d->ui.list->resizeColumnToContents(i);
-    }
-}
-
-void KShortcutsEditor::commit()
-{
-    for (QTreeWidgetItemIterator it(d->ui.list); (*it); ++it) {
-        if (KShortcutsEditorItem *item = dynamic_cast<KShortcutsEditorItem *>(*it)) {
-            item->commit();
+    // skip Name column as its section resize mode will take care of resizing to contents
+    for (int i = Name + 1; i < d->ui.list->columnCount(); i++) {
+        if (d->ui.list->isColumnHidden(i)) {
+            continue;
         }
+        d->ui.list->resizeColumnToContents(i);
     }
 }
 
@@ -227,16 +210,13 @@ void KShortcutsEditor::save()
     // undone on deletion! That would lead to weird problems. Changes to
     // Global Shortcuts would vanish completely. Changes to local shortcuts
     // would vanish for this session.
-    commit();
+    for (QTreeWidgetItemIterator it(d->ui.list); (*it); ++it) {
+        if (KShortcutsEditorItem *item = dynamic_cast<KShortcutsEditorItem *>(*it)) {
+            item->commit();
+        }
+    }
 }
 
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 75)
-void KShortcutsEditor::undoChanges()
-{
-    undo();
-}
-#endif
-
 void KShortcutsEditor::undo()
 {
     // This function used to crash sometimes when invoked by clicking on "cancel"
@@ -317,8 +297,18 @@ void KShortcutsEditorPrivate::initGUI(KShortcutsEditor::ActionTypes types, KShor
     ui.list->setAlternatingRowColors(true);
 
     // TODO listen to changes to global shortcuts
-    QObject::connect(delegate, &KShortcutsEditorDelegate::shortcutChanged, q, [this](const QVariant &newShortcut, const QModelIndex &index) {
-        capturedShortcut(newShortcut, index);
+    QObject::connect(delegate, &KShortcutsEditorDelegate::shortcutChanged, q, [this](const QKeySequence &newShortcut, const QModelIndex &index) {
+        // dispatch to the right handler
+        if (!index.isValid()) {
+            return;
+        }
+        int column = index.column();
+        KShortcutsEditorItem *item = itemFromIndex(ui.list, index);
+        Q_ASSERT(item);
+
+        if (column >= LocalPrimary && column <= GlobalAlternate) {
+            changeKeyShortcut(item, column, newShortcut);
+        }
     });
     // hide the editor widget chen its item becomes hidden
     QObject::connect(ui.searchFilter->searchLine(), &KTreeWidgetSearchLine::hiddenChanged, delegate, &KShortcutsEditorDelegate::hiddenBySearchLine);
@@ -370,6 +360,12 @@ bool KShortcutsEditorPrivate::addAction(QAction *action, QTreeWidgetItem *parent
         if (!m_hasAnyGlobalShortcuts) { // If one global action was found, skip
             m_hasAnyGlobalShortcuts = KGlobalAccel::self()->hasShortcut(action);
         }
+
+        if (!m_hasAnyLocalShortcuts) { // If one local action was found, skip
+            m_hasAnyLocalShortcuts = !KGlobalAccel::self()->hasShortcut(action);
+        }
+#else
+        m_hasAnyLocalShortcuts = true;
 #endif
 
         return true;
@@ -409,7 +405,7 @@ void KShortcutsEditorPrivate::allDefault()
 // static
 KShortcutsEditorItem *KShortcutsEditorPrivate::itemFromIndex(QTreeWidget *const w, const QModelIndex &index)
 {
-    QTreeWidgetItem *item = static_cast<QTreeWidgetHack *>(w)->itemFromIndex(index);
+    QTreeWidgetItem *item = w->itemFromIndex(index);
     if (item && item->type() == ActionItem) {
         return static_cast<KShortcutsEditorItem *>(item);
     }
@@ -432,21 +428,6 @@ QTreeWidgetItem *KShortcutsEditorPrivate::findOrMakeItem(QTreeWidgetItem *parent
 }
 
 // private slot
-void KShortcutsEditorPrivate::capturedShortcut(const QVariant &newShortcut, const QModelIndex &index)
-{
-    // dispatch to the right handler
-    if (!index.isValid()) {
-        return;
-    }
-    int column = index.column();
-    KShortcutsEditorItem *item = itemFromIndex(ui.list, index);
-    Q_ASSERT(item);
-
-    if (column >= LocalPrimary && column <= GlobalAlternate) {
-        changeKeyShortcut(item, column, newShortcut.value<QKeySequence>());
-    }
-}
-
 void KShortcutsEditorPrivate::changeKeyShortcut(KShortcutsEditorItem *item, uint column, const QKeySequence &capture)
 {
     // The keySequence we get is cleared by KKeySequenceWidget. No conflicts.
@@ -460,23 +441,6 @@ void KShortcutsEditorPrivate::changeKeyShortcut(KShortcutsEditorItem *item, uint
     item->setText(column, capture.toString(QKeySequence::NativeText));
 }
 
-void KShortcutsEditorPrivate::clearConfiguration()
-{
-    for (QTreeWidgetItemIterator it(ui.list); (*it); ++it) {
-        if (!(*it)->parent()) {
-            continue;
-        }
-
-        KShortcutsEditorItem *item = static_cast<KShortcutsEditorItem *>(*it);
-
-        changeKeyShortcut(item, LocalPrimary, QKeySequence());
-        changeKeyShortcut(item, LocalAlternate, QKeySequence());
-
-        changeKeyShortcut(item, GlobalPrimary, QKeySequence());
-        changeKeyShortcut(item, GlobalAlternate, QKeySequence());
-    }
-}
-
 void KShortcutsEditorPrivate::importConfiguration(KConfigBase *config)
 {
     Q_ASSERT(config);
